import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

/**
 * An object with mass that moves and has momentum conserving collisions
 * This object also reflects off of  the walls of the world,
 * which it represents with more vectors.  Based on the MovingThing class
 * from the asteroids scenario by Poul Henriksen.
 * 
 * @author Josh Fishburn
 */
public abstract class massiveObject extends Actor
{
    private Vector movement = new Vector();
    private int x = 0;
    private int y = 0;
    
    public massiveObject()
    {
    }
    
    /**
     * Create new thing initialised with given speed.
     */
    public massiveObject(Vector movement)
    {
        this.movement = movement;
    }

    /**
     * Move forward one step.
     */
    public void move() {
        x = (int)(getX() + movement.getX());
        y = (int)(getY() + movement.getY());
        
        //First, see if we've hit any walls
        if (x >= getWorld().getWidth()) {
            //We've hit the east wall; calculate new direction
            movement.add(new Vector(180, Math.abs(movement.getX())*2));
        }
        else if (y >= getWorld().getHeight()) {
            //We've hit the south wall; calculate new direction
            movement.add(new Vector(270, Math.abs(movement.getY())*2));
        }
        else if (x <= 0) {
            //We've hit the west wall; calculate new direction
            movement.add(new Vector(0, Math.abs(movement.getX())*2));
        }
        else if (y <= 0) {
            //We've hit the north wall; calculate new direction
            movement.add(new Vector(90, Math.abs(movement.getY())*2));
        }
        else {
            //collide();
        }
        setLocation(x, y);
        return;
    }
        
    
    public void collide() 
    {
        Actor ball1 = getOneIntersectingObject(ball.class);
        if(ball1 != null) {
            Vector temp = movement.copy();
            movement.add(((massiveObject)ball1).getMovement());
            ((massiveObject)ball1).getMovement().add(temp);
        }
        else
        {
            return;
        }
    }
    
    public Vector getMovement()
    {
        return movement;
    }
    
    public void setMovement(Vector movement)
    {
        this.movement = movement;
    }
    
}